==> sonic-pi-3.1.0-8-armv7h.pkg.tar.xz: usr/share/sonic-pi/samples/README.md <==
# Samples

All samples in this directory are from http://freesound.org and have
been placed in the public domain via the Creative Commons 0 License:

http://creativecommons.org/publicdomain/zero/1.0/

Many of the samples have been slightly modified and trimmed for use with
Sonic Pi.

Links to original samples:

## Drums

* `:drum_heavy_kick` - http://freesound.org/people/Zajo/sounds/4832/
* `:drum_tom_mid_soft` - http://www.freesound.org/people/menegass/sounds/100067/
* `:drum_tom_mid_hard` - http://www.freesound.org/people/menegass/sounds/100066/
* `:drum_tom_lo_soft` - http://www.freesound.org/people/menegass/sounds/100065/
* `:drum_tom_lo_hard` - http://www.freesound.org/people/menegass/sounds/100064/
* `:drum_tom_hi_soft` - http://www.freesound.org/people/menegass/sounds/100063/
* `:drum_tom_hi_hard` - http://www.freesound.org/people/menegass/sounds/100062/
* `:drum_splash_soft` - http://www.freesound.org/people/menegass/sounds/100061/
* `:drum_splash_hard` - http://www.freesound.org/people/menegass/sounds/100060/
* `:drum_snare_soft` - http://www.freesound.org/people/menegass/sounds/100059/
* `:drum_snare_hard` - http://www.freesound.org/people/menegass/sounds/100058/
* `:drum_cymbal_soft` - http://www.freesound.org/people/menegass/sounds/100057/
* `:drum_cymbal_hard` - http://www.freesound.org/people/menegass/sounds/100056/
* `:drum_cymbal_open` - http://www.freesound.org/people/menegass/sounds/100055/
* `:drum_cymbal_closed` - http://www.freesound.org/people/menegass/sounds/100053/
* `:drum_cymbal_pedal` - http://www.freesound.org/people/menegass/sounds/100054/
* `:drum_bass_soft` - http://www.freesound.org/people/menegass/sounds/100052/
* `:drum_bass_hard` - http://www.freesound.org/people/menegass/sounds/100051/
* `:drum_cowbell` - http://freesound.org/people/Neotone/sounds/75338/
* `:drum_roll` - http://freesound.org/people/Heigh-hoo/sounds/19433/


## Electric sounds

* `:elec_triangle` - http://www.freesound.org/people/looppool/sounds/13147/
* `:elec_snare` - http://www.freesound.org/people/looppool/sounds/13146/
* `:elec_lo_snare` - http://www.freesound.org/people/looppool/sounds/13145/
* `:elec_hi_snare` - http://www.freesound.org/people/looppool/sounds/13125/
* `:elec_mid_snare` - http://www.freesound.org/people/looppool/sounds/13132/
* `:elec_cymbal` - http://www.freesound.org/people/looppool/sounds/13143/
* `:elec_soft_kick` - http://www.freesound.org/people/looppool/sounds/13142/
* `:elec_filt_snare` - http://www.freesound.org/people/looppool/sounds/13141/
* `:elec_fuzz_tom` - http://www.freesound.org/people/looppool/sounds/13140/
* `:elec_chime` - http://www.freesound.org/people/looppool/sounds/13138/
* `:elec_bong` - http://www.freesound.org/people/looppool/sounds/13137/
* `:elec_twang` - http://www.freesound.org/people/looppool/sounds/13136/
* `:elec_wood` - http://www.freesound.org/people/looppool/sounds/13135/
* `:elec_pop` - http://www.freesound.org/people/looppool/sounds/13134/
* `:elec_beep` - http://www.freesound.org/people/looppool/sounds/13126/
* `:elec_blip` - http://www.freesound.org/people/looppool/sounds/13121/
* `:elec_blip2` - http://www.freesound.org/people/looppool/sounds/13120/
* `:elec_ping` - http://www.freesound.org/people/looppool/sounds/13119/
* `:elec_bell` - http://www.freesound.org/people/looppool/sounds/13116/
* `:elec_flip` - http://www.freesound.org/people/looppool/sounds/13114/
* `:elec_tick` - http://www.freesound.org/people/looppool/sounds/13113/
* `:elec_hollow_kick` - http://www.freesound.org/people/looppool/sounds/13099/
* `:elec_twip` - http://www.freesound.org/people/looppool/sounds/13094/
* `:elec_plip` - http://www.freesound.org/people/looppool/sounds/13093/
* `:elec_blup` - http://www.freesound.org/people/looppool/sounds/13092/


## Guitar

* `:guit_harmonics` - http://freesound.org/people/BStateham/sounds/141524/<
* `:guit_e_fifths` - http://freesound.org/people/Sub-d/sounds/46990/
* `:guit_e_slide` - http://freesound.org/people/Suva/sounds/2410/
* `:guit_em9` - http://www.freesound.org/people/Sub-d/sounds/46992/ 


## Misc

* `:misc_burp` - http://freesound.org/people/anas76/sounds/222022/
* `:misc_crow` - http://freesound.org/people/davidworksonline/sounds/54973/
* `:misc_cineboom` - http://freesound.org/people/Northern_Monkey/sounds/177242/


## Percussion

* `:perc_bell` - http://freesound.org/people/AlaskaRobotics/sounds/221515/
* `:perc_bell_2`- https://freesound.org/people/hullum/sounds/415559/
* `:perc_snap` - http://www.freesound.org/people/SoundCollectah/sounds/109400/
* `:perc_snap2` - http://www.freesound.org/people/Peram/sounds/158615/
* `:perc_swash` - http://freesound.org/people/qubodup/sounds/60009/
* `:perc_till` - http://freesound.org/people/Zott820/sounds/209578/
* `:perc_door` - https://freesound.org/people/hullum/sounds/415579/
* `:perc_impact_1` - https://freesound.org/people/hullum/sounds/415578/
* `:perc_impact_2` - https://freesound.org/people/hullum/sounds/415581/
* `:perc_swoosh` - https://freesound.org/people/hullum/sounds/415580/


## Ambient

* `:ambi_soft_buzz` - http://freesound.org/people/ludvique/sounds/71852/
* `:ambi_swoosh` - http://freesound.org/people/Halgrimm/sounds/169867/
* `:ambi_drone` - http://freesound.org/people/Autistic%20Lucario/sounds/195341/
* `:ambi_glass_hum` - http://freesound.org/people/kaligari/sounds/35391/
* `:ambi_glass_rub` - http://freesound.org/people/ani_music/sounds/198403/
* `:ambi_haunted_hum` - http://freesound.org/people/kaligari/sounds/35392/
* `:ambi_piano` - http://freesound.org/people/RutgerMuller/sounds/51245/
* `:ambi_lunar_land` - http://freesound.org/people/maqsim/sounds/172157/
* `:ambi_dark_woosh` - http://freesound.org/people/EcoDTR/sounds/27281/
* `:ambi_choir` - http://freesound.org/people/Exsomniel/sounds/207809/
* `:ambi_sauna` - https://freesound.org/people/hullum/sounds/415551/


## Bass

* `:bass_hit_c` - http://freesound.org/people/oceanictrancer/sounds/211614/
* `:bass_hard_c` - http://freesound.org/people/ani_music/sounds/165309/
* `:bass_thick_c` - http://freesound.org/people/ani_music/sounds/165314/
* `:bass_trance_c` - http://freesound.org/people/ani_music/sounds/165329/
* `:bass_drop_c` - http://freesound.org/people/ani_music/sounds/165320/ 
* `:bass_woodsy_c` - http://freesound.org/people/ani_music/sounds/165322/
* `:bass_voxy_c` - http://freesound.org/people/ani_music/sounds/165325/
* `:bass_voxy_hit_c` - http://freesound.org/people/ani_music/sounds/165327/
* `:bass_dnb_f` - http://freesound.org/people/Exsomniel/sounds/206134/


## Bass Drums

* `:bd_pure` - http://freesound.org/people/EKVelika/sounds/209571/
* `:bd_808` - http://freesound.org/people/EKVelika/sounds/208447/
* `:bd_zum` - http://freesound.org/people/n1ghthawk/sounds/172124/
* `:bd_gas`  - http://freesound.org/people/menegass/sounds/89460/
* `:bd_sone` - http://freesound.org/people/soneproject/sounds/223090/
* `:bd_haus` - http://freesound.org/people/Rodrigo%20The%20Mad/sounds/137722/
* `:bd_zome` - http://freesound.org/people/Dolfeus/sounds/55231/
* `:bd_boom` - http://freesound.org/people/Snapper4298/sounds/157245/
* `:bd_klub` - http://freesound.org/people/zgump/sounds/83262/
* `:bd_fat` - http://freesound.org/people/cubix/sounds/124386/
* `:bd_tek` - http://freesound.org/people/DWSD/sounds/171104/
* `:bd_ada` - http://www.freesound.org/people/adammusic18/sounds/208871/
* `:bd_mehackit` - https://freesound.org/people/hullum/sounds/415550/


## Snares

* `:sn_dub` - http://freesound.org/people/Adriak909/sounds/173142/
* `:sn_dolf` - http://freesound.org/people/Dolfeus/sounds/57534/
* `:sn_zome` - http://freesound.org/people/Dolfeus/sounds/55232/
* `:sn_generic` - https://freesound.org/people/hullum/sounds/415582/


## Loops

* `:loop_industrial` - http://freesound.org/people/godspine/sounds/222072/
* `:loop_compus` - http://freesound.org/people/godspine/sounds/212288/
* `:loop_amen` - http://freesound.org/people/Dolfeus/sounds/43389/
* `:loop_amen_full` - http://freesound.org/people/gowers/sounds/202537/
* `:loop_garzul` - http://freesound.org/people/Garzul/sounds/213524/
* `:loop_mika` - http://freesound.org/people/mika55/sounds/188551/
* `:loop_breakbeat` - http://freesound.org/people/Snapper4298/sounds/160354/
* `:loop_safari` - http://freesound.org/people/nemaavla/sounds/318759/
* `:loop_tabla` - http://freesound.org/people/lezaarth/sounds/242591/
* `:loop_3dprinter` - https://freesound.org/people/hullum/sounds/415571/
* `:loop_drone_g_97` - https://freesound.org/people/hullum/sounds/415570/
* `:loop_electric` - https://freesound.org/people/hullum/sounds/415569/
* `:loop_mehackit_1` - https://freesound.org/people/hullum/sounds/415568/
* `:loop_mehackit_2` - https://freesound.org/people/hullum/sounds/415575/
* `:loop_perc_1` - https://freesound.org/people/hullum/sounds/415574/
* `:loop_perc_2` - https://freesound.org/people/hullum/sounds/415573/
* `:loop_weirdo` - https://freesound.org/people/hullum/sounds/415572/


## Tabla

* `:tabla_tas1` - http://freesound.org/people/dio_333/sounds/130427/
* `:tabla_tas2` - http://freesound.org/people/dio_333/sounds/130425/
* `:tabla_tas3` - http://freesound.org/people/dio_333/sounds/130430/
* `:tabla_ke1` - http://freesound.org/people/dio_333/sounds/130413/
* `:tabla_ke2` - http://freesound.org/people/dio_333/sounds/130424/
* `:tabla_ke3` - http://freesound.org/people/dio_333/sounds/130423/
* `:tabla_na` - http://freesound.org/people/dio_333/sounds/130421/
* `:tabla_na_o` - http://freesound.org/people/dio_333/sounds/130422/
* `:tabla_tun1` - http://freesound.org/people/dio_333/sounds/130416/
* `:tabla_tun2` - http://freesound.org/people/dio_333/sounds/130419/
* `:tabla_tun3` - http://freesound.org/people/dio_333/sounds/130420/
* `:tabla_te1` - http://freesound.org/people/dio_333/sounds/130429/
* `:tabla_te2` - http://freesound.org/people/dio_333/sounds/130418/
* `:tabla_te_ne` - http://freesound.org/people/dio_333/sounds/130417/
* `:tabla_te_m` - http://freesound.org/people/dio_333/sounds/130415/
* `:tabla_ghe1` - http://freesound.org/people/dio_333/sounds/130406/
* `:tabla_ghe2` - http://freesound.org/people/dio_333/sounds/130405/
* `:tabla_ghe3` - http://freesound.org/people/dio_333/sounds/130404/
* `:tabla_ghe4` - http://freesound.org/people/dio_333/sounds/130411/
* `:tabla_ghe5` - http://freesound.org/people/dio_333/sounds/130410/
* `:tabla_ghe6` - http://freesound.org/people/dio_333/sounds/130409/
* `:tabla_ghe7` - http://freesound.org/people/dio_333/sounds/130408/
* `:tabla_ghe8` - http://freesound.org/people/dio_333/sounds/130414/
* `:tabla_dhec` - http://freesound.org/people/dio_333/sounds/130407/
* `:tabla_na_s` - http://freesound.org/people/dio_333/sounds/130428/
* `:tabla_re` - http://freesound.org/people/dio_333/sounds/130427/


# Vinyl

* `:vinyl_backspin` - http://freesound.org/people/il112/sounds/182316/
* `:vinyl_rewind` - http://freesound.org/people/TasmanianPower/sounds/162493/
* `:vinyl_scratch` - http://freesound.org/people/hello_flowers/sounds/28681/
* `:vinyl_hiss` - http://freesound.org/people/veezay/sounds/130393/


# Glitchy sounds

* `:glitch_bass_g` - https://freesound.org/people/hullum/sounds/415549/
* `:glitch_perc_1` - https://freesound.org/people/hullum/sounds/415548/
* `:glitch_perc_2` - https://freesound.org/people/hullum/sounds/415555/
* `:glitch_perc_3` - https://freesound.org/people/hullum/sounds/415554/
* `:glitch_perc_4` - https://freesound.org/people/hullum/sounds/415553/
* `:glitch_perc_5` - https://freesound.org/people/hullum/sounds/415552/
* `:glitch_robot_1` - https://freesound.org/people/hullum/sounds/415557/
* `:glitch_robot_2` - https://freesound.org/people/hullum/sounds/415556/


# Mehackit sounds

* `:mehackit_phone_1` - https://freesound.org/people/hullum/sounds/415577/
* `:mehackit_phone_2` - https://freesound.org/people/hullum/sounds/415576/
* `:mehackit_phone_3` - https://freesound.org/people/hullum/sounds/415562/
* `:mehackit_phone_4` - https://freesound.org/people/hullum/sounds/415563/
* `:mehackit_robot_1` - https://freesound.org/people/hullum/sounds/415560/
* `:mehackit_robot_2` - https://freesound.org/people/hullum/sounds/415561/
* `:mehackit_robot_3` - https://freesound.org/people/hullum/sounds/415566/
* `:mehackit_robot_4` - https://freesound.org/people/hullum/sounds/415567/
* `:mehackit_robot_5` - https://freesound.org/people/hullum/sounds/415564/
* `:mehackit_robot_6` - https://freesound.org/people/hullum/sounds/415565/
* `:mehackit_robot_7` - https://freesound.org/people/hullum/sounds/415558/

==> sonic-pi-3.2.2-2-armv7h.pkg.tar.xz: usr/share/sonic-pi/samples/README.md <==
# Samples

All samples in this directory are from http://freesound.org and have
been placed in the public domain via the Creative Commons 0 License:

http://creativecommons.org/publicdomain/zero/1.0/

Many of the samples have been slightly modified and trimmed for use with
Sonic Pi. 

Links to original samples:

## Drums

* `:drum_heavy_kick` - http://freesound.org/people/Zajo/sounds/4832/
* `:drum_tom_mid_soft` - http://www.freesound.org/people/menegass/sounds/100067/
* `:drum_tom_mid_hard` - http://www.freesound.org/people/menegass/sounds/100066/
* `:drum_tom_lo_soft` - http://www.freesound.org/people/menegass/sounds/100065/
* `:drum_tom_lo_hard` - http://www.freesound.org/people/menegass/sounds/100064/
* `:drum_tom_hi_soft` - http://www.freesound.org/people/menegass/sounds/100063/
* `:drum_tom_hi_hard` - http://www.freesound.org/people/menegass/sounds/100062/
* `:drum_splash_soft` - http://www.freesound.org/people/menegass/sounds/100061/
* `:drum_splash_hard` - http://www.freesound.org/people/menegass/sounds/100060/
* `:drum_snare_soft` - http://www.freesound.org/people/menegass/sounds/100059/
* `:drum_snare_hard` - http://www.freesound.org/people/menegass/sounds/100058/
* `:drum_cymbal_soft` - http://www.freesound.org/people/menegass/sounds/100057/
* `:drum_cymbal_hard` - http://www.freesound.org/people/menegass/sounds/100056/
* `:drum_cymbal_open` - http://www.freesound.org/people/menegass/sounds/100055/
* `:drum_cymbal_closed` - http://www.freesound.org/people/menegass/sounds/100053/
* `:drum_cymbal_pedal` - http://www.freesound.org/people/menegass/sounds/100054/
* `:drum_bass_soft` - http://www.freesound.org/people/menegass/sounds/100052/
* `:drum_bass_hard` - http://www.freesound.org/people/menegass/sounds/100051/
* `:drum_cowbell` - http://freesound.org/people/Neotone/sounds/75338/
* `:drum_roll` - http://freesound.org/people/Heigh-hoo/sounds/19433/


## Electric sounds

* `:elec_triangle` - http://www.freesound.org/people/looppool/sounds/13147/
* `:elec_snare` - http://www.freesound.org/people/looppool/sounds/13146/
* `:elec_lo_snare` - http://www.freesound.org/people/looppool/sounds/13145/
* `:elec_hi_snare` - http://www.freesound.org/people/looppool/sounds/13125/
* `:elec_mid_snare` - http://www.freesound.org/people/looppool/sounds/13132/
* `:elec_cymbal` - http://www.freesound.org/people/looppool/sounds/13143/
* `:elec_soft_kick` - http://www.freesound.org/people/looppool/sounds/13142/
* `:elec_filt_snare` - http://www.freesound.org/people/looppool/sounds/13141/
* `:elec_fuzz_tom` - http://www.freesound.org/people/looppool/sounds/13140/
* `:elec_chime` - http://www.freesound.org/people/looppool/sounds/13138/
* `:elec_bong` - http://www.freesound.org/people/looppool/sounds/13137/
* `:elec_twang` - http://www.freesound.org/people/looppool/sounds/13136/
* `:elec_wood` - http://www.freesound.org/people/looppool/sounds/13135/
* `:elec_pop` - http://www.freesound.org/people/looppool/sounds/13134/
* `:elec_beep` - http://www.freesound.org/people/looppool/sounds/13126/
* `:elec_blip` - http://www.freesound.org/people/looppool/sounds/13121/
* `:elec_blip2` - http://www.freesound.org/people/looppool/sounds/13120/
* `:elec_ping` - http://www.freesound.org/people/looppool/sounds/13119/
* `:elec_bell` - http://www.freesound.org/people/looppool/sounds/13116/
* `:elec_flip` - http://www.freesound.org/people/looppool/sounds/13114/
* `:elec_tick` - http://www.freesound.org/people/looppool/sounds/13113/
* `:elec_hollow_kick` - http://www.freesound.org/people/looppool/sounds/13099/
* `:elec_twip` - http://www.freesound.org/people/looppool/sounds/13094/
* `:elec_plip` - http://www.freesound.org/people/looppool/sounds/13093/
* `:elec_blup` - http://www.freesound.org/people/looppool/sounds/13092/


## Guitar

* `:guit_harmonics` - http://freesound.org/people/BStateham/sounds/141524/
* `:guit_e_fifths` - http://freesound.org/people/Sub-d/sounds/46990/
* `:guit_e_slide` - http://freesound.org/people/Suva/sounds/2410/
* `:guit_em9` - http://www.freesound.org/people/Sub-d/sounds/46992/ 


## Misc

* `:misc_burp` - http://freesound.org/people/anas76/sounds/222022/
* `:misc_crow` - http://freesound.org/people/davidworksonline/sounds/54973/
* `:misc_cineboom` - http://freesound.org/people/Northern_Monkey/sounds/177242/ **(link deprecated)**


## Percussion

* `:perc_bell` - http://freesound.org/people/AlaskaRobotics/sounds/221515/
* `:perc_bell_2`- https://freesound.org/people/hullum/sounds/415559/
* `:perc_snap` - http://www.freesound.org/people/SoundCollectah/sounds/109400/
* `:perc_snap2` - http://www.freesound.org/people/Peram/sounds/158615/
* `:perc_swash` - http://freesound.org/people/qubodup/sounds/60009/
* `:perc_till` - http://freesound.org/people/Zott820/sounds/209578/
* `:perc_door` - https://freesound.org/people/hullum/sounds/415579/
* `:perc_impact_1` - https://freesound.org/people/hullum/sounds/415578/
* `:perc_impact_2` - https://freesound.org/people/hullum/sounds/415581/
* `:perc_swoosh` - https://freesound.org/people/hullum/sounds/415580/


## Ambient

* `:ambi_soft_buzz` - http://freesound.org/people/ludvique/sounds/71852/
* `:ambi_swoosh` - http://freesound.org/people/Halgrimm/sounds/169867/
* `:ambi_drone` - http://freesound.org/people/Autistic%20Lucario/sounds/195341/
* `:ambi_glass_hum` - http://freesound.org/people/kaligari/sounds/35391/
* `:ambi_glass_rub` - http://freesound.org/people/ani_music/sounds/198403/
* `:ambi_haunted_hum` - http://freesound.org/people/kaligari/sounds/35392/
* `:ambi_piano` - http://freesound.org/people/RutgerMuller/sounds/51245/
* `:ambi_lunar_land` - http://freesound.org/people/maqsim/sounds/172157/
* `:ambi_dark_woosh` - http://freesound.org/people/EcoDTR/sounds/27281/
* `:ambi_choir` - http://freesound.org/people/Exsomniel/sounds/207809/
* `:ambi_sauna` - https://freesound.org/people/hullum/sounds/415551/


## Bass

* `:bass_hit_c` - http://freesound.org/people/oceanictrancer/sounds/211614/ **(link deprecated)**
* `:bass_hard_c` - http://freesound.org/people/ani_music/sounds/165309/
* `:bass_thick_c` - http://freesound.org/people/ani_music/sounds/165314/
* `:bass_trance_c` - http://freesound.org/people/ani_music/sounds/165329/
* `:bass_drop_c` - http://freesound.org/people/ani_music/sounds/165320/ 
* `:bass_woodsy_c` - http://freesound.org/people/ani_music/sounds/165322/
* `:bass_voxy_c` - http://freesound.org/people/ani_music/sounds/165325/
* `:bass_voxy_hit_c` - http://freesound.org/people/ani_music/sounds/165327/
* `:bass_dnb_f` - http://freesound.org/people/Exsomniel/sounds/206134/


## Bass Drums

* `:bd_pure` - http://freesound.org/people/EKVelika/sounds/209571/
* `:bd_808` - http://freesound.org/people/EKVelika/sounds/208447/
* `:bd_zum` - http://freesound.org/people/n1ghthawk/sounds/172124/
* `:bd_gas`  - http://freesound.org/people/menegass/sounds/89460/
* `:bd_sone` - http://freesound.org/people/soneproject/sounds/223090/
* `:bd_haus` - http://freesound.org/people/Rodrigo%20The%20Mad/sounds/137722/
* `:bd_zome` - http://freesound.org/people/Dolfeus/sounds/55231/
* `:bd_boom` - http://freesound.org/people/Snapper4298/sounds/157245/
* `:bd_klub` - http://freesound.org/people/zgump/sounds/83262/
* `:bd_fat` - http://freesound.org/people/cubix/sounds/124386/
* `:bd_tek` - http://freesound.org/people/DWSD/sounds/171104/
* `:bd_ada` - http://www.freesound.org/people/adammusic18/sounds/208871/
* `:bd_mehackit` - https://freesound.org/people/hullum/sounds/415550/


## Snares

* `:sn_dub` - http://freesound.org/people/Adriak909/sounds/173142/
* `:sn_dolf` - http://freesound.org/people/Dolfeus/sounds/57534/
* `:sn_zome` - http://freesound.org/people/Dolfeus/sounds/55232/
* `:sn_generic` - https://freesound.org/people/hullum/sounds/415582/


## Loops

* `:loop_industrial` - http://freesound.org/people/godspine/sounds/222072/
* `:loop_compus` - http://freesound.org/people/godspine/sounds/212288/
* `:loop_amen` - http://freesound.org/people/Dolfeus/sounds/43389/
* `:loop_amen_full` - http://freesound.org/people/gowers/sounds/202537/
* `:loop_garzul` - http://freesound.org/people/Garzul/sounds/213524/
* `:loop_mika` - http://freesound.org/people/mika55/sounds/188551/
* `:loop_breakbeat` - http://freesound.org/people/Snapper4298/sounds/160354/
* `:loop_safari` - http://freesound.org/people/nemaavla/sounds/318759/
* `:loop_tabla` - http://freesound.org/people/lezaarth/sounds/242591/
* `:loop_3dprinter` - https://freesound.org/people/hullum/sounds/415571/
* `:loop_drone_g_97` - https://freesound.org/people/hullum/sounds/415570/
* `:loop_electric` - https://freesound.org/people/hullum/sounds/415569/
* `:loop_mehackit_1` - https://freesound.org/people/hullum/sounds/415568/
* `:loop_mehackit_2` - https://freesound.org/people/hullum/sounds/415575/
* `:loop_perc_1` - https://freesound.org/people/hullum/sounds/415574/
* `:loop_perc_2` - https://freesound.org/people/hullum/sounds/415573/
* `:loop_weirdo` - https://freesound.org/people/hullum/sounds/415572/


## Tabla

* `:tabla_tas1` - http://freesound.org/people/dio_333/sounds/130427/ **(link deprecated)**
* `:tabla_tas2` - http://freesound.org/people/dio_333/sounds/130425/ **(link deprecated)**
* `:tabla_tas3` - http://freesound.org/people/dio_333/sounds/130430/ **(link deprecated)**
* `:tabla_ke1` - http://freesound.org/people/dio_333/sounds/130413/ **(link deprecated)**
* `:tabla_ke2` - http://freesound.org/people/dio_333/sounds/130424/ **(link deprecated)**
* `:tabla_ke3` - http://freesound.org/people/dio_333/sounds/130423/ **(link deprecated)**
* `:tabla_na` - http://freesound.org/people/dio_333/sounds/130421/ **(link deprecated)**
* `:tabla_na_o` - http://freesound.org/people/dio_333/sounds/130422/ **(link deprecated)**
* `:tabla_tun1` - http://freesound.org/people/dio_333/sounds/130416/ **(link deprecated)**
* `:tabla_tun2` - http://freesound.org/people/dio_333/sounds/130419/ **(link deprecated)**
* `:tabla_tun3` - http://freesound.org/people/dio_333/sounds/130420/ **(link deprecated)**
* `:tabla_te1` - http://freesound.org/people/dio_333/sounds/130429/ **(link deprecated)**
* `:tabla_te2` - http://freesound.org/people/dio_333/sounds/130418/ **(link deprecated)**
* `:tabla_te_ne` - http://freesound.org/people/dio_333/sounds/130417/ **(link deprecated)**
* `:tabla_te_m` - http://freesound.org/people/dio_333/sounds/130415/ **(link deprecated)**
* `:tabla_ghe1` - http://freesound.org/people/dio_333/sounds/130406/ **(link deprecated)**
* `:tabla_ghe2` - http://freesound.org/people/dio_333/sounds/130405/ **(link deprecated)**
* `:tabla_ghe3` - http://freesound.org/people/dio_333/sounds/130404/ **(link deprecated)**
* `:tabla_ghe4` - http://freesound.org/people/dio_333/sounds/130411/ **(link deprecated)**
* `:tabla_ghe5` - http://freesound.org/people/dio_333/sounds/130410/ **(link deprecated)**
* `:tabla_ghe6` - http://freesound.org/people/dio_333/sounds/130409/ **(link deprecated)**
* `:tabla_ghe7` - http://freesound.org/people/dio_333/sounds/130408/ **(link deprecated)**
* `:tabla_ghe8` - http://freesound.org/people/dio_333/sounds/130414/ **(link deprecated)**
* `:tabla_dhec` - http://freesound.org/people/dio_333/sounds/130407/ **(link deprecated)**
* `:tabla_na_s` - http://freesound.org/people/dio_333/sounds/130428/ **(link deprecated)**
* `:tabla_re` - http://freesound.org/people/dio_333/sounds/130427/ **(link deprecated)**


# Vinyl

* `:vinyl_backspin` - http://freesound.org/people/il112/sounds/182316/
* `:vinyl_rewind` - http://freesound.org/people/TasmanianPower/sounds/162493/
* `:vinyl_scratch` - http://freesound.org/people/hello_flowers/sounds/28681/
* `:vinyl_hiss` - http://freesound.org/people/veezay/sounds/130393/


# Glitchy sounds

* `:glitch_bass_g` - https://freesound.org/people/hullum/sounds/415549/
* `:glitch_perc_1` - https://freesound.org/people/hullum/sounds/415548/
* `:glitch_perc_2` - https://freesound.org/people/hullum/sounds/415555/
* `:glitch_perc_3` - https://freesound.org/people/hullum/sounds/415554/
* `:glitch_perc_4` - https://freesound.org/people/hullum/sounds/415553/
* `:glitch_perc_5` - https://freesound.org/people/hullum/sounds/415552/
* `:glitch_robot_1` - https://freesound.org/people/hullum/sounds/415557/
* `:glitch_robot_2` - https://freesound.org/people/hullum/sounds/415556/


# Mehackit sounds

* `:mehackit_phone_1` - https://freesound.org/people/hullum/sounds/415577/
* `:mehackit_phone_2` - https://freesound.org/people/hullum/sounds/415576/
* `:mehackit_phone_3` - https://freesound.org/people/hullum/sounds/415562/
* `:mehackit_phone_4` - https://freesound.org/people/hullum/sounds/415563/
* `:mehackit_robot_1` - https://freesound.org/people/hullum/sounds/415560/
* `:mehackit_robot_2` - https://freesound.org/people/hullum/sounds/415561/
* `:mehackit_robot_3` - https://freesound.org/people/hullum/sounds/415566/
* `:mehackit_robot_4` - https://freesound.org/people/hullum/sounds/415567/
* `:mehackit_robot_5` - https://freesound.org/people/hullum/sounds/415564/
* `:mehackit_robot_6` - https://freesound.org/people/hullum/sounds/415565/
* `:mehackit_robot_7` - https://freesound.org/people/hullum/sounds/415558/
